==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.proxy/src/com/openexchange/proxy/ImageContentTypeRestriction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.proxy;

import java.util.Locale;
import java.util.regex.Pattern;

/**
 * {@link ImageContentTypeRestriction} - A {@link ContentTypeRestriction} for images. <code>"Content-Type"</code> header must match pattern
 * <code>"image/*"</code>.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class ImageContentTypeRestriction extends ContentTypeRestriction {

    private static final ImageContentTypeRestriction INSTANCE = new ImageContentTypeRestriction();

    /**
     * Gets the singleton instance.
     *
     * @return The singleton instance
     */
    public static ImageContentTypeRestriction getInstance() {
        return INSTANCE;
    }

    /**
     * The regex pattern for <code>"image/*"</code>.
     */
    private final Pattern pattern;

    /**
     * Initializes a new {@link ImageContentTypeRestriction}.
     */
    private ImageContentTypeRestriction() {
        super();
        pattern = Pattern.compile(wildcardToRegex("image/*"));
    }

    @Override
    public boolean allow(final Response response) {
        final Header header = response.getResponseHeader(CONTENT_TYPE);
        final String lcValue;
        {
            final String value = header.getValue();
            if (null == value) {
                /*
                 * Content-Type header missing
                 */
                return false;
            }
            lcValue = value.toLowerCase(Locale.ENGLISH).trim();
        }
        if (pattern.matcher(lcValue).matches()) {
            return true;
        }
        /*
         * No match found
         */
        return false;
    }

    @Override
    public String getDescription() {
        return "Content-Type header must match: image/*";
    }

}

==> open-xchange-core_7.2.1.orig.tar.bz2: open-xchange-core-7.2.1/com.openexchange.proxy/src/com/openexchange/proxy/ImageContentTypeRestriction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.proxy;

import java.util.regex.Pattern;

/**
 * {@link ImageContentTypeRestriction} - A {@link ContentTypeRestriction} for images. <code>"Content-Type"</code> header must match pattern
 * <code>"image/*"</code>.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class ImageContentTypeRestriction extends ContentTypeRestriction {

    private static final ImageContentTypeRestriction INSTANCE = new ImageContentTypeRestriction();

    /**
     * Gets the singleton instance.
     *
     * @return The singleton instance
     */
    public static ImageContentTypeRestriction getInstance() {
        return INSTANCE;
    }

    /**
     * The regex pattern for <code>"image/*"</code>.
     */
    private final Pattern pattern;

    /**
     * Initializes a new {@link ImageContentTypeRestriction}.
     */
    private ImageContentTypeRestriction() {
        super();
        pattern = Pattern.compile(wildcardToRegex("image/*"));
    }

    @Override
    public boolean allow(final Response response) {
        final Header header = response.getResponseHeader(CONTENT_TYPE);
        final String lcValue;
        {
            final String value = header.getValue();
            if (null == value) {
                /*
                 * Content-Type header missing
                 */
                return false;
            }
            lcValue = toLowerCase(value).trim();
        }
        if (pattern.matcher(lcValue).matches()) {
            return true;
        }
        /*
         * No match found
         */
        return false;
    }

    @Override
    public String getDescription() {
        return "Content-Type header must match: image/*";
    }

    private static String toLowerCase(final CharSequence chars) {
        final int length = chars.length();
        final StringBuilder builder = new StringBuilder(length);
        for (int i = 0; i < length; i++) {
            final char c = chars.charAt(i);
            builder.append((c >= 'A') && (c <= 'Z') ? (char) (c ^ 0x20) : c);
        }
        return builder.toString();
    }

}
